kmBlockTest-package: k-means like blockmodeling of one-mode and linked networks

kmBlockTest-packageR Documentation

k-means like blockmodeling of one-mode and linked networks

Description

k-means like blockmodeling of one-mode and linked networks

Details

The DESCRIPTION file: This package was not yet installed at build time.
Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most important functions ~~

Author(s)

Aleš Žiberna [aut, cre]

Maintainer: Aleš Žiberna <ales.ziberna@fdv.uni-lj.si>

References

~~ Literature or other references for background information ~~

See Also

~~ Optional links to other man pages, e.g. ~~ ~~ <pkg> ~~


kmBlockTest documentation built on June 1, 2022, 3 p.m.