| kmBlockTest-package | R Documentation |
k-means like blockmodeling of one-mode and linked networks
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most important functions ~~
Aleš Žiberna [aut, cre]
Maintainer: Aleš Žiberna <ales.ziberna@fdv.uni-lj.si>
~~ Literature or other references for background information ~~
~~ Optional links to other man pages, e.g. ~~
~~ <pkg> ~~
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.